@@ -2,7 +2,7 @@
 #-------------------------------------------------------------------------
 # Module: Gbook
 # Author: Jos (josvd@live.nl)
-# Version: 1.0.1
+# Version: 1.1
 #
 #-------------------------------------------------------------------------
 # CMS - CMS Made Simple is (c) 2009 by Ted Kulp (wishy@cmsmadesimple.org)
@@ -38,19 +38,19 @@ class Gbook extends CMSModule
 
 	function GetFriendlyName()
 	{
-		return $this->Lang('friendlyname');
+		return $this->GetPreference('custom_modulename', $this->Lang('friendlyname'));
 	}
 
 	function GetVersion()
 	{
-		return '1.0.1';
+		return '1.1';
 	}
 
 	function GetHelp()
 	{
     $helptxt = $this->Lang('help') . '<form action="https://www.paypal.com/cgi-bin/webscr" method="post"><input type="hidden" name="cmd" value="_donations"><input type="hidden" name="business" value="josvd@live.nl"><input type="hidden" name="item_name" value="Jos"><input type="hidden" name="item_number" value="CMSms Gbook Module"><input type="hidden" name="currency_code" value="EUR"><input type="image" src="https://www.paypalobjects.com/en_US/i/btn/btn_donateCC_LG.gif" border="0" name="submit" alt="PayPal - The safer, easier way to pay online!"><img alt="" border="0" src="https://www.paypalobjects.com/nl_NL/i/scr/pixel.gif" width="1" height="1"></form><br />
 <h3>Copyright and License</h3>
-<p>Copyright &copy; 2012, Jos &lt;<a href="mailto:josvd@live.nl">josvd@live.nl</a>&gt;. All Rights Are Reserved.</p>
+<p>Copyright &copy; 2012-2013, Jos &lt;<a href="mailto:josvd@live.nl">josvd@live.nl</a>&gt;. All Rights Are Reserved.</p>
 <p>This module has been released under the <a href="http://www.gnu.org/licenses/licenses.html#GPL">GNU Public License v3</a>. However, as a special exception to the GPL, this software is distributed as an addon module to CMS Made Simple. You may only use this software when there is a clear and obvious indication in the admin section that the site was built with CMS Made Simple.</p>
 ';
 		return $helptxt;
@@ -83,7 +83,7 @@ class Gbook extends CMSModule
 
 	function GetAdminSection()
 	{
-		return 'content';
+		return $this->GetPreference('admin_section', 'content');
 	}
 
 	function GetAdminDescription()
@@ -163,14 +163,14 @@ class Gbook extends CMSModule
 		return $this->Lang('postinstall', $this->Lang('friendlyname'));
 	}
   
-	function GetEventDescription( $eventname )
+	function GetEventDescription($eventname)
 	{
-		return $this->lang('eventdesc-' . $eventname);
+		return; // $this->lang('eventdesc_' . $eventname);
 	}
 
-	function GetEventHelp( $eventname )
+	function GetEventHelp($eventname)
 	{
-		return $this->lang('eventhelp-' . $eventname);
+		return; // $this->lang('eventhelp_' . $eventname);
 	}
 	
 	function SearchResult($returnid, $entry_id, $attr = '')
@@ -186,7 +186,7 @@ class Gbook extends CMSModule
 				$result[0] = $this->GetFriendlyName();
 
 				//1 position is the title
-				$result[1] = trim(trim(trim($entry['title'] . ' / ' . $entry['name']),'/'));
+				$result[1] = trim(trim($entry->title . ' / ' . $entry->name),'/');
 
 				//2 position is the URL to the title.
 				$prettyurl = ''; //'gbook/' . $entry_id . '/' . $returnid;
