@@ -141,6 +141,12 @@ switch ($params['mode'])
 	case 'deletefromham':
 		$item = Gbook_utils::GetEntry($params['entryid']);
 		Gbook_utils::b8_exec('DeleteFromHam', $item->title . ' ' . $item->rawmessage);
+		$query = "UPDATE " . cms_db_prefix() . "module_gbook_entries SET 
+								approved = ?,
+								approved_date = NOW(),
+								approved_by = ?
+							WHERE entry_id = ?";
+		$db->Execute($query, array(0, get_userid(), $params['entryid']));
 		$params = array('gbookid' => $params['gbookid'], 'active_tab' => 'entries');
 		$this->Redirect($id, 'defaultadmin', '', $params);
 		break;
@@ -149,6 +155,12 @@ switch ($params['mode'])
 	case 'deletefromspam':
 		$item = Gbook_utils::GetEntry($params['entryid']);
 		Gbook_utils::b8_exec('DeleteFromSpam', $item->title . ' ' . $item->rawmessage);
+		$query = "UPDATE " . cms_db_prefix() . "module_gbook_entries SET 
+								approved = ?,
+								approved_date = NOW(),
+								approved_by = ?
+							WHERE entry_id = ?";
+		$db->Execute($query, array(0, get_userid(), $params['entryid']));
 		$params = array('gbookid' => $params['gbookid'], 'active_tab' => 'entries');
 		$this->Redirect($id, 'defaultadmin', '', $params);
 		break;
