@@ -64,7 +64,7 @@ $fielderrors = array();
 $fields = array('name', 'email', 'title', 'message');
 foreach ( $fields as $field )
 {
-	$params[$field] = empty($params[$field]) ? '' : $params[$field];
+	$params[$field] = empty($params[$field]) ? '' : html_entity_decode($params[$field],ENT_QUOTES);
 }
 $params['notify'] = empty($params['notify']) ? 0 : 1;
 
@@ -77,11 +77,6 @@ if( $_SERVER['REQUEST_METHOD'] == 'POST' && isset($params['submit']) )
 	$receivedtoken = explode('-', $params['token']);
 	if ( array_key_exists($receivedtoken[0], $token) && $receivedtoken[1] == md5($gbook['gbook_id'] . $token[$receivedtoken[0]]) )
 	{
-		$fields = array('name', 'email', 'title', 'message');
-		foreach ($fields as $field)
-		{
-			$params[$field] = html_entity_decode($params[$field],ENT_QUOTES);
-		}
 		$addentry = Gbook_utils::AddEntry($gbook['gbook_id'], $params['name'], $params['email'], $params['title'], $params['message'], $params['notify']);
 
 		if ( is_array($addentry) && key($addentry) == 'entry added' )
@@ -94,36 +89,45 @@ if( $_SERVER['REQUEST_METHOD'] == 'POST' && isset($params['submit']) )
 			{
 				// send email to admin
 				$cmsmailer = cms_utils::get_module('CMSMailer');
-				if( $cmsmailer )
+				$users = (array)unserialize($this->GetPreference('send_notifications_to'));
+				if( $cmsmailer && !empty($users) )
 				{
-					$admin_email = trim($this->GetPreference('send_notifications_to'));
-					if( !empty($admin_email) )
+					foreach ( $users as $user )
 					{
-						$cmsmailer->AddAddress( $admin_email );
-						$cmsmailer->SetSubject( $gbook['admin_notification_subject'] );
-						$cmsmailer->IsHTML( false );
-
-						$body = $CMS_VERSION < '1.11' ? $this->ProcessTemplateFromData($gbook['admin_notification_message']) : $smarty->fetch('string:'.$gbook['admin_notification_message']);
-						$cmsmailer->SetBody( $body );
-						$cmsmailer->Send();
+						if ( $user < 0 )
+						{
+							// group
+							$groupusers = cmsms()->GetUserOperations()->LoadUsersInGroup(abs($user));
+							foreach ( $groupusers as $groupuser)
+							{
+								if ( $groupuser->active ) $cmsmailer->AddAddress($groupuser->email);
+							}
+						}
+						else
+						{
+							// individual user
+							$user_email = cmsms()->GetUserOperations()->LoadUserById($user)->email;
+							$cmsmailer->AddAddress($user_email);
+						}
 					}
+					$cmsmailer->SetSubject($gbook['admin_notification_subject']);
+					$cmsmailer->IsHTML(false);
+					$body = $CMS_VERSION < '1.11' ? $this->ProcessTemplateFromData($gbook['admin_notification_message']) : $smarty->fetch('string:'.$gbook['admin_notification_message']);
+					$cmsmailer->SetBody($body);
+					$cmsmailer->Send();
+					$cmsmailer->ClearAddresses();
 				}				
 			}
 			
 			// display submission response
+			$response = ($spamrate <= $this->GetPreference('max_spamrate_active', 0.6)) ? 'submission_response' : 'submission_response_spam';
 			if ( $CMS_VERSION < '1.11' )
 			{
-				if ( $spamrate <= $this->GetPreference('max_spamrate_active', 0.6) )
-					echo $this->ProcessTemplateFromData($gbook['submission_response']);
-				else
-					echo $this->ProcessTemplateFromData($gbook['submission_response_spam']);					
+				echo $this->ProcessTemplateFromData($gbook[$response]);					
 			}
 			else
 			{
-				if ( $spamrate <= $this->GetPreference('max_spamrate_active', 0.6) )
-					echo $smarty->display('string:'.$gbook['submission_response']);
-				else
-					echo $smarty->display('string:'.$gbook['submission_response_spam']);
+				echo $smarty->display('string:'.$gbook[$response]);
 			}
 		}
 		elseif ( is_array($addentry) )
