@@ -16,8 +16,7 @@ if( !$this->CheckPermission('Modify Site Preferences') )
 	return;
 }
 
-$this->SetPreference('send_notifications_to', trim($params['send_notifications_to']));
-//$this->SetPreference('not_send_spamnotifications', isset($params['not_send_spamnotifications']) ? $params['not_send_spamnotifications'] : 0);
+$this->SetPreference('send_notifications_to', serialize($params['send_notifications_to']));
 
 if ( is_numeric($params['max_spamrate_active']) && abs($params['max_spamrate_active']) <= 1 )
 	$this->SetPreference('max_spamrate_active', abs($params['max_spamrate_active']));
