@@ -12,8 +12,10 @@
 $smarty->assign('startform', $this->CreateFormStart ($id, 'updateoptions', $returnid));
 $smarty->assign('endform', $this->CreateFormEnd ());
 
+$userslist = Gbook_utils::GetUsers();
+$selectedusers = (array)unserialize($this->GetPreference('send_notifications_to', ''));
 $smarty->assign('send_notifications_to', $this->Lang('send_notifications_to'));
-$smarty->assign('input_send_notifications_to', $this->CreateInputText($id, 'send_notifications_to', $this->GetPreference('send_notifications_to',''),50,255));
+$smarty->assign('input_send_notifications_to', $this->CreateInputSelectList($id, 'send_notifications_to[]', $userslist, $selectedusers, 6));
 
 $smarty->assign('max_spamrate_active', $this->Lang('max_spamrate_active'));
 $smarty->assign('input_max_spamrate_active', $this->CreateInputText($id, 'max_spamrate_active', $this->GetPreference('max_spamrate_active', 0.6),5,5) . ' ' . $this->Lang('max_spamrate_active_help'));
