@@ -73,11 +73,11 @@ $lang['resetwarning'] = 'Are you sure you want to reset the template code to def
 
 
 //Options
-$lang['send_notifications_to'] = 'Email address to receive notification of new entries';
+$lang['send_notifications_to'] = 'Send notification of new entries to editor';
 //$lang['not_send_spamnotifications'] = 'Do not send notifications for suspected spam entries';
 $lang['max_spamrate_active'] = 'Maximum spamrating to automatically set an entry active on submit';
 $lang['max_spamrate_active_help'] = 'between 0 and 1, default 0.6. Lower value means tighter setting.';
-$lang['max_spamrate_notify'] = 'Maximum spamrating for sending a notification to admin';
+$lang['max_spamrate_notify'] = 'Maximum spamrating for sending a notification to editor';
 $lang['max_spamrate_notify_help'] = 'between 0 and 1, default 0.9. Higher value will increase the chance of getting notifications of spam entries.';
 $lang['max_spamrate_save'] = 'Maximum spamrating for saving a new entry';
 $lang['max_spamrate_save_help'] = 'between 0 and 1, default 0.9. Lower value will increase the chance of losing legitimate entries.';
