@@ -566,6 +566,24 @@ class Gbook_utils
 		return sprintf("%01.2f", $rating) . ' <span style="display:inline-block; width:10px; height:10px; border:1px solid #666; background-color:rgb('.$red.', '.$green.', 0);"><span>';
 	}
 
+	public static function GetUsers()
+	{
+		$users = array();
+		$gCms = cmsms();
+		$groupops = $gCms->GetGroupOperations();
+		$allgroups = $groupops->LoadGroups();
+		foreach ($allgroups as $onegroup)
+		{
+			$users[lang('group') . ': ' . $onegroup->name] = $onegroup->id * -1;
+		}
+		$userops = $gCms->GetUserOperations();
+		$allusers = $userops->LoadUsers();
+		foreach ($allusers as $oneuser)
+		{
+			$users[$oneuser->username] = $oneuser->id;
+		}
+		return $users;
+	}
 
 }
 ?>
\ No newline at end of file
