@@ -191,8 +191,7 @@ if( !$stylesheetops->CheckExistingStylesheetName('Gbook module') && file_exists(
 
 
 // create preferences
-$user_email = cmsms()->GetUserOperations()->LoadUserById(get_userid())->email;
-$this->SetPreference('send_notifications_to', $user_email);
+$this->SetPreference('send_notifications_to', get_userid());
 $this->SetPreference('max_spamrate_active', 0.6);
 $this->SetPreference('max_spamrate_notify', 0.9);
 $this->SetPreference('max_spamrate_save', 0.9);
