@@ -14,13 +14,17 @@ if (!isset($gCms)) exit;
 
 switch( $oldversion )
 {
-	case "0.8":
-
-		//current_version: 1.0
-
 	case "1.0":
+	case "1.0.1":
+		$this->SetPreference('send_notifications_to', get_userid());
+		$this->SetPreference('custom_modulename', $this->Lang('friendlyname'));
+		$this->SetPreference('admin_section', 'content');
+
+		//current_version: 1.1
+
+	case "1.1":
 		
-		//current_version: 1.0.1
+		//current_version: 1.1.1
 		
 }
 
